==> biemond-jdk7-0.4.12.tar.gz: biemond-jdk7-0.4.12/spec/classes/urandomfix_spec.rb <==
require 'spec_helper'

describe 'jdk7::urandomfix' , :type => :class do

  it { should contain_package('rng-tools').with_ensure('present') }

  describe "Windows" do
    let(:facts) {{ :kernel          => 'Windows',
                   :operatingsystem => 'Windows',
                   :osfamily        => 'Windows'}}
    it do
      expect { should contain_exec("set urandom /etc/sysconfig/rngd")
             }.to raise_error(Puppet::Error, /Unrecognized osfamily Windows, please use it on a Linux host/)
    end
  end
  describe "SunOS" do
    let(:facts) {{ :kernel          => 'SunOS',
                   :operatingsystem => 'Solaris',
                   :osfamily        => 'Solaris'}}
    it do
      expect { should contain_exec("set urandom /etc/sysconfig/rngd")
             }.to raise_error(Puppet::Error, /Unrecognized osfamily Solaris, please use it on a Linux host/)
    end
  end

  describe "CentOS" do
    let(:facts) {{ :operatingsystem => 'CentOS' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat' }}

    describe "on operatingsystem CentOS" do
      it do
        should contain_exec("set urandom /etc/sysconfig/rngd").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
      it do
        should contain_exec("chkconfig rngd").with({
            'user'    => 'root',
            'command' => "chkconfig --add rngd",
          })
      end
    end

  end
  describe "RedHat" do
    let(:facts) {{ :operatingsystem => 'RedHat' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat' }}

    describe "on operatingsystem RedHat" do
      it do
        should contain_exec("set urandom /etc/sysconfig/rngd").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
      it do
        should contain_exec("chkconfig rngd").with({
            'user'    => 'root',
            'command' => "chkconfig --add rngd",
          })
      end
    end

  end
  describe "OracleLinux" do
    let(:facts) {{ :operatingsystem => 'OracleLinux' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat' }}

    describe "on operatingsystem OracleLinux" do
      it do
        should contain_exec("set urandom /etc/sysconfig/rngd").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
      it do
        should contain_exec("chkconfig rngd").with({
            'user'    => 'root',
            'command' => "chkconfig --add rngd",
          })
      end
    end

  end

  ['Ubuntu','Debian','SLES'].each do |system|
    let(:facts) {{ :operatingsystem => system ,
                   :kernel          => 'Linux',
                   :osfamily        => 'Debian' }}

    describe "on operatingsystem #{system}" do
      it do
        should contain_exec("set urandom /etc/default/rng-tools").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rng-tools").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
    end
  end

end

==> biemond-jdk7-0.5.3.tar.gz: biemond-jdk7-0.5.3/spec/classes/urandomfix_spec.rb <==
require 'spec_helper'

describe 'jdk7::urandomfix' , :type => :class do

  it { should contain_package('rng-tools').with_ensure('present') }

  describe "Windows" do
    let(:facts) {{ :kernel          => 'Windows',
                   :operatingsystem => 'Windows',
                   :osfamily        => 'Windows'}}
    it do
      expect { should contain_exec("set urandom /etc/sysconfig/rngd")
             }.to raise_error(Puppet::Error, /Unrecognized osfamily Windows, please use it on a Linux host/)
    end
  end
  describe "SunOS" do
    let(:facts) {{ :kernel          => 'SunOS',
                   :operatingsystem => 'Solaris',
                   :osfamily        => 'Solaris'}}
    it do
      expect { should contain_exec("set urandom /etc/sysconfig/rngd")
             }.to raise_error(Puppet::Error, /Unrecognized osfamily Solaris, please use it on a Linux host/)
    end
  end

  describe "CentOS" do
    let(:facts) {{ :operatingsystem => 'CentOS' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat',
                   :operatingsystemmajrelease => '6' }}

    describe "on operatingsystem CentOS" do
      it do
        should contain_exec("set urandom /etc/sysconfig/rngd").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
      it do
        should contain_exec("chkconfig rngd").with({
            'user'    => 'root',
            'command' => "chkconfig --add rngd",
          })
      end
    end

  end
  describe "RedHat" do
    let(:facts) {{ :operatingsystem => 'RedHat' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat',
                   :operatingsystemmajrelease => '7' }}

    describe "on operatingsystem RedHat" do
      it do
        should contain_exec('set urandom /lib/systemd/system/rngd.service').with({
            'user'  => 'root',
          })
      end
      it do
        should contain_exec('systemctl-daemon-reload').with({
            'command' => 'systemctl --system daemon-reload',
          })
      end

      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
    end

  end
  describe "OracleLinux" do
    let(:facts) {{ :operatingsystem => 'OracleLinux' ,
                   :kernel          => 'Linux',
                   :osfamily        => 'RedHat',
                   :operatingsystemmajrelease => '6' }}

    describe "on operatingsystem OracleLinux" do
      it do
        should contain_exec("set urandom /etc/sysconfig/rngd").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rngd").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
      it do
        should contain_exec("chkconfig rngd").with({
            'user'    => 'root',
            'command' => "chkconfig --add rngd",
          })
      end
    end

  end

  ['Ubuntu','Debian','SLES'].each do |system|
    let(:facts) {{ :operatingsystem => system ,
                   :kernel          => 'Linux',
                   :osfamily        => 'Debian' }}

    describe "on operatingsystem #{system}" do
      it do
        should contain_exec("set urandom /etc/default/rng-tools").with({
            'user'  => 'root',
          })
      end
      it do
        should contain_service("rng-tools").with({
            'ensure'     => 'running',
            'enable'     => true,
          })
      end
    end
  end

end
